==> pipev-0.1.0.tar.gz: pipev-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

requires = ['pip>=7']
tests_require = ['pytest', 'pytest-cache', 'pytest-cov']
dev_require = ['wheel', 'bumpversion', 'twine'] + tests_require


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


setup(
    name="pipev",
    version='0.1.0',
    description="Expand environment variables in pip requirement files.",
    long_description="\n\n".join([open("README.rst").read()]),
    license=open('LICENSE').read(),
    author="Sebastian Vetter",
    author_email="seb@roadsi.de",
    url="https://www.github.com/elbaschid/pipev",
    install_requires=requires,
    entry_points={'console_scripts': ['pipev = pipev:main']},
    classifiers=[
        'Development Status :: 1 - Planning',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: CPython'],
    extras_require={'test': tests_require,
                    'dev': dev_require},
    cmdclass={'test': PyTest})

==> pipev-0.1.1.tar.gz: pipev-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

requires = ['pip>=7']
tests_require = ['pytest', 'pytest-cache', 'pytest-cov']
dev_require = ['wheel', 'bumpversion', 'twine'] + tests_require


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


setup(
    name="pipev",
    version='0.1.1',
    description="Expand environment variables in pip requirement files.",
    long_description="\n\n".join([open("README.rst").read()]),
    license=open('LICENSE').read(),
    author="Sebastian Vetter",
    author_email="seb@roadsi.de",
    url="https://www.github.com/elbaschid/pipev",
    packages=['pipev'],
    install_requires=requires,
    entry_points={'console_scripts': ['pipev = pipev.main:main']},
    classifiers=[
        'Development Status :: 1 - Planning',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: CPython'],
    extras_require={'test': tests_require,
                    'dev': dev_require},
    cmdclass={'test': PyTest})
